@@ -39,6 +39,10 @@ class Pipeline(Generic[R]):
         self._source.put(GenericPipe.get_kill_word())
 
     def _register(self, process: Process):
+        """_register
+        This method will register a process as parent
+        to know when it should stop
+        """
         self._parents.append(process)
 
     def task(self, task: Callable[[R], S], count: int = 1) -> "Pipeline[S]":
