@@ -1,6 +1,7 @@
 from multiprocessing import Queue
 from typing import Callable, Iterable, TypeVar
-from .generic import GenericPipe
+
+from olympipe.pipes.task import TaskPipe
 
 R = TypeVar("R")
 S = TypeVar("S")
@@ -9,12 +10,12 @@ S = TypeVar("S")
 __version__ = "0.1.0"
 
 
-class ExplodePipe(GenericPipe[R, S]):
+class ExplodePipe(TaskPipe[R, S]):
     def __init__(
         self, source: "Queue[R]", task: Callable[[R], Iterable[S]], target: "Queue[S]"
     ):
-        super().__init__(source, target)
-        self._task = task
+
+        super().__init__(source, task, target)  # type: ignore
 
     def dispatch_to_next(self, processed: Iterable[S]):  # type: ignore
         for p in processed:
